(require 'dictem)
(setq dictem-server "server")
(dictem-initialize)
(global-set-key "\C-cs" 'dictem-run-search)
(global-set-key "\C-cm" 'dictem-run-match)
(global-set-key "\C-cd" 'dictem-run-define)
(global-set-key "\C-c\M-r" 'dictem-run-show-server)
(global-set-key "\C-c\M-i" 'dictem-run-show-info)
(global-set-key "\C-c\M-b" 'dictem-run-show-databases)
